@@ -4,7 +4,7 @@ Main interface for robomaker service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_robomaker import (
         Client,
         ListDeploymentJobsPaginator,
@@ -21,10 +21,8 @@ Usage::
         RoboMakerClient,
     )
 
-    session = boto3.Session()
-
-    client: RoboMakerClient = boto3.client("robomaker")
-    session_client: RoboMakerClient = session.client("robomaker")
+    session = Session()
+    client: RoboMakerClient = session.client("robomaker")
 
     list_deployment_jobs_paginator: ListDeploymentJobsPaginator = client.get_paginator("list_deployment_jobs")
     list_fleets_paginator: ListFleetsPaginator = client.get_paginator("list_fleets")
